DomotApiModbus
=========================

DomotApiModbus provide a simple interface to get and set value on a modbus device.

It is composed of a generic modbus class, and specific device class.

In the current version, class for Unelvent Ideo 450 is implemented
